@@ -91,7 +91,7 @@ goog.debug.Logger = function(name) {
 
   /**
    * Handlers that are listening to this logger.
-   * @private {Array.<Function>}
+   * @private {Array<Function>}
    */
   this.handlers_ = null;
 };
@@ -111,7 +111,7 @@ goog.define('goog.debug.Logger.ENABLE_HIERARCHY', true);
 
 if (!goog.debug.Logger.ENABLE_HIERARCHY) {
   /**
-   * @type {!Array.<Function>}
+   * @type {!Array<Function>}
    * @private
    */
   goog.debug.Logger.rootHandlers_ = [];
@@ -261,7 +261,7 @@ goog.debug.Logger.Level.ALL = new goog.debug.Logger.Level('ALL', 0);
 
 /**
  * The predefined levels.
- * @type {!Array.<!goog.debug.Logger.Level>}
+ * @type {!Array<!goog.debug.Logger.Level>}
  * @final
  */
 goog.debug.Logger.Level.PREDEFINED_LEVELS = [
@@ -544,8 +544,7 @@ goog.debug.Logger.prototype.log = function(level, msg, opt_exception) {
       msg = msg();
     }
 
-    this.doLogRecord_(this.getLogRecord(
-        level, msg, opt_exception, goog.debug.Logger.prototype.log));
+    this.doLogRecord_(this.getLogRecord(level, msg, opt_exception));
   }
 };
 
@@ -556,13 +555,11 @@ goog.debug.Logger.prototype.log = function(level, msg, opt_exception) {
  * @param {string} msg The string message.
  * @param {Error|Object=} opt_exception An exception associated with the
  *     message.
- * @param {Function=} opt_fnStackContext A function to use as the base
- *     of the stack trace used in the log record.
  * @return {!goog.debug.LogRecord} A log record.
  * @suppress {es5Strict}
  */
 goog.debug.Logger.prototype.getLogRecord = function(
-    level, msg, opt_exception, opt_fnStackContext) {
+    level, msg, opt_exception) {
   if (goog.debug.LogBuffer.isBufferingEnabled()) {
     var logRecord =
         goog.debug.LogBuffer.getInstance().addRecord(level, msg, this.name_);
@@ -570,17 +567,7 @@ goog.debug.Logger.prototype.getLogRecord = function(
     logRecord = new goog.debug.LogRecord(level, String(msg), this.name_);
   }
   if (opt_exception) {
-    var context;
-    if (goog.STRICT_MODE_COMPATIBLE) {
-      context = opt_fnStackContext || goog.debug.Logger.prototype.getLogRecord;
-    } else {
-      context = opt_fnStackContext || arguments.callee.caller;
-    }
-
     logRecord.setException(opt_exception);
-    logRecord.setExceptionText(
-        goog.debug.exposeException(opt_exception,
-            opt_fnStackContext || goog.debug.Logger.prototype.getLogRecord));
   }
   return logRecord;
 };
@@ -771,6 +758,7 @@ goog.debug.Logger.prototype.addChild_ = function(name, logger) {
  * There is a single global LogManager object that is used to maintain a set of
  * shared state about Loggers and log services. This is loosely based on the
  * java class java.util.logging.LogManager.
+ * @const
  */
 goog.debug.LogManager = {};
 
@@ -778,7 +766,7 @@ goog.debug.LogManager = {};
 /**
  * Map of logger names to logger objects.
  *
- * @type {!Object.<string, !goog.debug.Logger>}
+ * @type {!Object<string, !goog.debug.Logger>}
  * @private
  */
 goog.debug.LogManager.loggers_ = {};
@@ -808,7 +796,7 @@ goog.debug.LogManager.initialize = function() {
 
 /**
  * Returns all the loggers.
- * @return {!Object.<string, !goog.debug.Logger>} Map of logger names to logger
+ * @return {!Object<string, !goog.debug.Logger>} Map of logger names to logger
  *     objects.
  */
 goog.debug.LogManager.getLoggers = function() {
