@@ -16,6 +16,7 @@ goog.provide('goog.fx.AbstractDragDropTest');
 goog.setTestOnly('goog.fx.AbstractDragDropTest');
 
 goog.require('goog.array');
+goog.require('goog.dom.TagName');
 goog.require('goog.events.EventType');
 goog.require('goog.functions');
 goog.require('goog.fx.AbstractDragDrop');
@@ -211,7 +212,7 @@ function testBoxOverlaps() {
  * Checks whether a given box overlaps any of given DnD target boxes.
  *
  * @param {goog.math.Box} box The box to check.
- * @param {Array.<Object>} targets The array of targets with boxes to check
+ * @param {Array<Object>} targets The array of targets with boxes to check
  *     if they overlap with the given box.
  * @return {boolean} Whether the box overlaps any of the target boxes.
  */
@@ -461,8 +462,8 @@ function testIsInside() {
 
 function testAddingRemovingScrollableContainers() {
   var group = new goog.fx.AbstractDragDrop();
-  var el1 = document.createElement('div');
-  var el2 = document.createElement('div');
+  var el1 = document.createElement(goog.dom.TagName.DIV);
+  var el2 = document.createElement(goog.dom.TagName.DIV);
 
   assertEquals(0, group.scrollableContainers_.length);
 
@@ -563,8 +564,8 @@ function testScrollBeforeMoveDrag() {
 
 function testMouseMove_mouseOutBeforeThreshold() {
   // Setup dragdrop and item
-  var itemEl = document.createElement('div');
-  var childEl = document.createElement('div');
+  var itemEl = document.createElement(goog.dom.TagName.DIV);
+  var childEl = document.createElement(goog.dom.TagName.DIV);
   itemEl.appendChild(childEl);
   var add = new goog.fx.AbstractDragDrop();
   var item = new goog.fx.DragDropItem(itemEl);
@@ -597,7 +598,7 @@ function testMouseMove_mouseOutBeforeThreshold() {
 
 function testGetDragElementPosition() {
   var testGroup = new goog.fx.AbstractDragDrop();
-  var sourceEl = document.createElement('div');
+  var sourceEl = document.createElement(goog.dom.TagName.DIV);
   document.body.appendChild(sourceEl);
 
   var pageOffset = goog.style.getPageOffset(sourceEl);
@@ -625,7 +626,7 @@ function drawTargets(targets, multiplier) {
   cont.innerHTML = '';
   for (var i = 0; i < targets.length; i++) {
     var box = targets[i].box_;
-    var el = document.createElement('div');
+    var el = document.createElement(goog.dom.TagName.DIV);
     el.style.top = (box.top * multiplier) + 'px';
     el.style.left = (box.left * multiplier) + 'px';
     el.style.width = ((box.right - box.left) * multiplier) + 'px';
