@@ -28,6 +28,7 @@ uxbindir=${uxbindir:=/opt/puppetlabs/bin}
 # symlinks of server binaries
 symbindir=${symbindir:=/opt/puppetlabs/server/bin}
 app_prefix=${app_prefix:=/opt/puppetlabs/server/apps/${real_name}}
+dest_apps_dir="${DESTDIR}${app_prefix}"
 app_data=${app_data:=/opt/puppetlabs/server/data/${real_name}}
 app_logdir=${app_logdir:=/var/log/puppetlabs/${real_name}}
 system_config_dir=${system_config_dir:=${app_prefix}/config}
@@ -131,13 +132,16 @@ function task_install_source_deb_systemd {
 # Install the ezbake package software. This step is used during RPM &
 # Debian packaging during the 'install' phases.
 function task_install {
-    install -d -m 0755 "${DESTDIR}${app_prefix}"
+    install -d -m 0755 "${dest_apps_dir}"
     install -d -m 0770 "${DESTDIR}${app_data}"
-    install -m 0644 puppet-server-release.jar "${DESTDIR}${app_prefix}"
-    install -m 0755 ext/ezbake-functions.sh "${DESTDIR}${app_prefix}"
-    install -m 0644 ext/ezbake.manifest "${DESTDIR}${app_prefix}"
+    install -m 0644 puppet-server-release.jar "${dest_apps_dir}"
+    install -m 0755 ext/ezbake-functions.sh "${dest_apps_dir}"
+    install -m 0644 ext/ezbake.manifest "${dest_apps_dir}"
     install -d -m 0755 "${DESTDIR}${projconfdir}/conf.d"
 
+      install -m 0644 jruby-9k.jar "${dest_apps_dir}"
+      install -m 0644 jruby-1_7.jar "${dest_apps_dir}"
+  
     install -d -m 0755 "${DESTDIR}${system_config_dir}/services.d"
     install -d -m 0755 "${DESTDIR}${projconfdir}/services.d"
 
@@ -149,27 +153,33 @@ function task_install {
     install -m 0644 ext/config/conf.d/global.conf "${DESTDIR}${projconfdir}/conf.d/global.conf"
     install -m 0644 ext/config/conf.d/web-routes.conf "${DESTDIR}${projconfdir}/conf.d/web-routes.conf"
     install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
+    install -m 0644 ext/config/conf.d/metrics.conf "${DESTDIR}${projconfdir}/conf.d/metrics.conf"
     install -m 0644 ext/config/conf.d/webserver.conf "${DESTDIR}${projconfdir}/conf.d/webserver.conf"
     install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
 
-    install -d -m 0755 "${DESTDIR}${app_prefix}/scripts"
-    install -m 0755 install.sh "${DESTDIR}${app_prefix}/scripts"
+    install -d -m 0755 "${dest_apps_dir}/scripts"
+    install -m 0755 install.sh "${dest_apps_dir}/scripts"
 
-    install -d -m 0755 "${DESTDIR}${app_prefix}/cli"
-    install -d -m 0755 "${DESTDIR}${app_prefix}/cli/apps"
+    install -d -m 0755 "${dest_apps_dir}/cli"
+    install -d -m 0755 "${dest_apps_dir}/cli/apps"
     install -d -m 0755 "${DESTDIR}${bindir}"
     install -m 0755 "ext/bin/${real_name}" "${DESTDIR}${bindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${symbindir}"
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
-    install -m 0755 ext/cli/foreground "${DESTDIR}${app_prefix}/cli/apps/foreground"
-    install -m 0755 ext/cli/reload "${DESTDIR}${app_prefix}/cli/apps/reload"
-    install -m 0755 ext/cli/stop "${DESTDIR}${app_prefix}/cli/apps/stop"
-    install -m 0755 ext/cli/start "${DESTDIR}${app_prefix}/cli/apps/start"
-    install -m 0755 ext/cli/gem "${DESTDIR}${app_prefix}/cli/apps/gem"
-    install -m 0755 ext/cli/irb "${DESTDIR}${app_prefix}/cli/apps/irb"
-    install -m 0755 ext/cli/ruby "${DESTDIR}${app_prefix}/cli/apps/ruby"
+    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
+    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
+    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
+    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
+    install -m 0755 ext/cli/gem "${dest_apps_dir}/cli/apps/gem"
+    install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
+    install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
+
+if [ -e "ext/cli_defaults/cli-defaults.sh" ]; then
+    install -m 0755 ext/cli_defaults/cli-defaults.sh "${dest_apps_dir}/cli/"
+fi
+
     install -d -m 0755 "${DESTDIR}${rundir}"
     install -d -m 700 "${DESTDIR}${app_logdir}"
 }
