@@ -1,4 +1,6 @@
-(def ps-version "2.7.2")
+(def ps-version "5.0.0")
+(def jruby-1_7-version "1.7.27-1")
+(def jruby-9k-version "9.1.11.0-1")
 
 (defn deploy-info
   [url]
@@ -27,19 +29,22 @@
         "least 5G for best performance during test runs.")
       default-heap-size)))
 
+(def figwheel-version "0.3.7")
+(def cljsbuild-version "1.1.5")
+
 (defproject puppetlabs/puppetserver ps-version
   :description "Puppet Server"
 
   :min-lein-version "2.7.1"
 
-  :parent-project {:coords [puppetlabs/clj-parent "0.1.7"]
+  :parent-project {:coords [puppetlabs/clj-parent "1.2.1"]
                    :inherit [:managed-dependencies]}
 
   :dependencies [[org.clojure/clojure]
 
                  [slingshot]
-                 ;; we need to exclude snakeyaml because JRuby also brings it in
-                 [clj-yaml nil :exclusions [org.yaml/snakeyaml]]
+                 [circleci/clj-yaml]
+                 [org.yaml/snakeyaml]
                  [commons-lang]
                  [commons-io]
 
@@ -48,6 +53,7 @@
                  [me.raynes/fs]
                  [liberator]
                  [org.apache.commons/commons-exec]
+                 [io.dropwizard.metrics/metrics-core]
 
                  ;; We do not currently use this dependency directly, but
                  ;; we have documentation that shows how users can use it to
@@ -58,9 +64,17 @@
                  ;; in different versions of the three different logback artifacts
                  [net.logstash.logback/logstash-logback-encoder]
 
-                 [puppetlabs/jruby-utils "0.4.0"]
+                 [puppetlabs/jruby-utils "0.10.0"]
+                 [puppetlabs/jruby-deps ~jruby-1_7-version]
+
+                 ;; JRuby 1.7.x and trapperkeeper (via core.async) both bring in
+                 ;; asm dependencies.  Deferring to clj-parent to resolve the version.
+                 [org.ow2.asm/asm-all]
+
                  [puppetlabs/trapperkeeper]
                  [puppetlabs/trapperkeeper-authorization]
+                 [puppetlabs/trapperkeeper-comidi-metrics]
+                 [puppetlabs/trapperkeeper-metrics]
                  [puppetlabs/trapperkeeper-scheduler]
                  [puppetlabs/trapperkeeper-status]
                  [puppetlabs/kitchensink]
@@ -69,7 +83,12 @@
                  [puppetlabs/dujour-version-check]
                  [puppetlabs/http-client]
                  [puppetlabs/comidi]
-                 [puppetlabs/i18n]]
+                 [puppetlabs/i18n]
+
+                 ;; dependencies for clojurescript dashboard
+                 [puppetlabs/cljs-dashboard-widgets]
+                 [org.clojure/clojurescript]
+                 [cljs-http "0.1.36"]]
 
   :main puppetlabs.trapperkeeper.main
 
@@ -77,26 +96,30 @@
 
   :source-paths ["src/clj"]
   :java-source-paths ["src/java"]
+
   :test-paths ["test/unit" "test/integration"]
-  :resource-paths ["resources" "src/ruby"]
+  :resource-paths ["resources" "src/ruby" "target/js-resources"]
 
   :repositories [["releases" "http://nexus.delivery.puppetlabs.net/content/repositories/releases/"]
                  ["snapshots" "http://nexus.delivery.puppetlabs.net/content/repositories/snapshots/"]]
 
   :plugins [[lein-parent "0.3.1"]
-            [puppetlabs/i18n "0.4.3"]]
+            [puppetlabs/i18n "0.8.0"]]
 
   :uberjar-name "puppet-server-release.jar"
   :lein-ezbake {:vars {:user "puppet"
                        :group "puppet"
                        :build-type "foss"
-                       :java-args "-Xms2g -Xmx2g -XX:MaxPermSize=256m"
+                       :java-args ~(str "-Xms2g -Xmx2g "
+                                     "-Djruby.logger.class=com.puppetlabs.jruby_utils.jruby.Slf4jLogger")
                        :repo-target "PC1"
                        :bootstrap-source :services-d
                        :logrotate-enabled false}
                 :resources {:dir "tmp/ezbake-resources"}
                 :config-dir "ezbake/config"
-                :system-config-dir "ezbake/system-config"}
+                :system-config-dir "ezbake/system-config"
+                :additional-uberjars [[puppetlabs/jruby-deps ~jruby-9k-version]
+                                      [puppetlabs/jruby-deps ~jruby-1_7-version]]}
 
   :deploy-repositories [["releases" ~(deploy-info "http://nexus.delivery.puppetlabs.net/content/repositories/releases/")]
                         ["snapshots" ~(deploy-info "http://nexus.delivery.puppetlabs.net/content/repositories/snapshots/")]]
@@ -107,20 +130,64 @@
   ;; code that we have.
   :classifiers [["test" :testutils]]
 
+  :cljsbuild {:builds {:app {:source-paths ["src/cljs"]
+                             :compiler {:output-to     "target/js-resources/puppetlabs/puppetserver/public/js/puppetserver-dashboard.js"
+                                        :output-dir    "target/js-resources/puppetlabs/puppetserver/public/js/out"
+                                        :asset-path   "js/out"
+                                        :optimizations :none
+                                        :pretty-print  true
+                                        :main "puppetlabs.puppetserver.dashboard.production"}}}}
+  :hooks [leiningen.cljsbuild]
+
   :profiles {:dev {:source-paths  ["dev"]
                    :dependencies  [[org.clojure/tools.namespace]
-                                   [puppetlabs/trapperkeeper-webserver-jetty9]
+                                   [puppetlabs/trapperkeeper-webserver-jetty9 nil]
                                    [puppetlabs/trapperkeeper-webserver-jetty9 nil :classifier "test"]
                                    [puppetlabs/trapperkeeper nil :classifier "test" :scope "test"]
+                                   [puppetlabs/trapperkeeper-metrics :classifier "test" :scope "test"]
                                    [puppetlabs/kitchensink nil :classifier "test" :scope "test"]
                                    [ring-basic-authentication]
                                    [ring-mock]
                                    [grimradical/clj-semver "0.3.0" :exclusions [org.clojure/clojure]]
-                                   [beckon]]
+                                   [beckon]
+                                   [com.cemerick/url "0.1.1"]
+
+                                   ;; Including this to avoid a logback version conflict when running
+                                   ;; 'lein figwheel'.
+                                   [ch.qos.logback/logback-classic]
+
+                                   ;; dependencies for cljs development
+                                   [leiningen "2.7.1" :exclusions [org.codehaus.plexus/plexus-utils
+                                                                   org.clojure/tools.cli]]
+                                   [cljsbuild ~cljsbuild-version]
+
+                                   [figwheel ~figwheel-version :exclusions [org.clojure/clojure]]]
+                   ;; dev profile config for clojurescript dev
+                   :plugins [[lein-cljsbuild ~cljsbuild-version]
+                             [lein-figwheel ~figwheel-version
+                              :exclusions [org.clojure/clojure
+                                           org.clojure/core.cache
+                                           commons-io
+                                           commons-codec]]]
+                   :figwheel {:http-server-root "puppetlabs/puppetserver/public"
+                              :server-port 3449
+                              :repl false}
+                   :cljsbuild {:builds {:app {:source-paths ["dev-cljs"]
+                                              :compiler {:main "puppetlabs.puppetserver.dashboard.dev"
+                                                         :source-map true}}}}
                    ; SERVER-332, enable SSLv3 for unit tests that exercise SSLv3
                    :jvm-opts      ["-Djava.security.properties=./dev-resources/java.security"]}
 
              :testutils {:source-paths ^:replace ["test/unit" "test/integration"]}
+             :test {
+                    ;; NOTE: In core.async version 0.2.382, the default size for
+                    ;; the core.async dispatch thread pool was reduced from
+                    ;; (42 + (2 * num-cpus)) to... eight.  The jruby metrics tests
+                    ;; use core.async and need more than eight threads to run
+                    ;; properly; this setting overrides the default value.  Without
+                    ;; it the metrics tests will hang.
+                    :jvm-opts ["-Dclojure.core.async.pool-size=50"]
+                    }
 
              :ezbake {:dependencies ^:replace [;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
                                                ;; NOTE: we need to explicitly pass in `nil` values
@@ -140,37 +207,36 @@
                                                ;; brings in its own version, and older versions of
                                                ;; lein depend on clojure 1.6.
                                                [org.clojure/clojure nil]
-                                               [puppetlabs/puppetserver ~ps-version]
+                                               [puppetlabs/puppetserver ~ps-version :exclusions [puppetlabs/jruby-deps]]
                                                [puppetlabs/trapperkeeper-webserver-jetty9 nil]
                                                [org.clojure/tools.nrepl nil]]
-                      :plugins [[puppetlabs/lein-ezbake "1.1.5"]]
+                      :plugins [[puppetlabs/lein-ezbake "1.4.0"]]
                       :name "puppetserver"}
              :uberjar {:aot [puppetlabs.trapperkeeper.main]
-                       :dependencies [[puppetlabs/trapperkeeper-webserver-jetty9]]}
+                       :dependencies [[puppetlabs/trapperkeeper-webserver-jetty9 nil]]}
              :ci {:plugins [[lein-pprint "1.1.1"]]}
-             :voom {:plugins [[lein-voom "0.1.0-20150115_230705-gd96d771" :exclusions [org.clojure/clojure]]]}}
+             :voom {:plugins [[lein-voom "0.1.0-20150115_230705-gd96d771" :exclusions [org.clojure/clojure]]]}
+             :jruby9k {:dependencies [[puppetlabs/jruby-deps ~jruby-9k-version]]}}
 
   :test-selectors {:integration :integration
                    :unit (complement :integration)}
 
-  :aliases {"gem" ["trampoline" "run" "-m" "puppetlabs.puppetserver.cli.gem"]
-            "ruby" ["trampoline" "run" "-m" "puppetlabs.puppetserver.cli.ruby"]
-            "irb" ["trampoline" "run" "-m" "puppetlabs.puppetserver.cli.irb"]}
+  :aliases {"gem" ["trampoline" "run" "-m" "puppetlabs.puppetserver.cli.gem" "--config" "./dev/puppetserver.conf" "--"]
+            "ruby" ["trampoline" "run" "-m" "puppetlabs.puppetserver.cli.ruby" "--config" "./dev/puppetserver.conf" "--"]
+            "irb" ["trampoline" "run" "-m" "puppetlabs.puppetserver.cli.irb" "--config" "./dev/puppetserver.conf" "--"]}
 
   ; tests use a lot of PermGen (jruby instances)
-  :jvm-opts ["-XX:MaxPermSize=256m"
+  :jvm-opts ["-Djruby.logger.class=com.puppetlabs.jruby_utils.jruby.Slf4jLogger"
+             "-XX:+UseG1GC"
              ~(str "-Xms" (heap-size "1G" "min"))
              ~(str "-Xmx" (heap-size "2G" "max"))]
 
-  :repl-options {:init-ns user}
+  :repl-options {:init-ns dev-tools}
 
-  ;; NOTE: jruby-stdlib packages some unexpected things inside
-  ;; of its jar.  e.g., it puts a pre-built copy of the bouncycastle
-  ;; jar into its META-INF directory.  This is highly undesirable
-  ;; for projects that already have a dependency on a different
-  ;; version of bouncycastle.  Therefore, when building uberjars,
-  ;; you should take care to exclude the things that you don't want
-  ;; in your final jar.  Here is an example of how you could exclude
-  ;; that from the final uberjar:
-  :uberjar-exclusions [#"META-INF/jruby.home/lib/ruby/shared/org/bouncycastle"]
+  ;; This is used to merge the locales.clj of all the dependencies into a single
+  ;; file inside the uberjar
+  :uberjar-merge-with {"locales.clj"  [(comp read-string slurp)
+                                       (fn [new prev]
+                                         (if (map? prev) [new prev] (conj prev new)))
+                                       #(spit %1 (pr-str %2))]}
   )
