@@ -8,12 +8,15 @@
             [puppetlabs.services.jruby-pool-manager.jruby-schemas :as jruby-schemas]
             [puppetlabs.services.jruby-pool-manager.jruby-core :as jruby-core]
             [puppetlabs.services.jruby.puppet-environments :as puppet-env]
+            [puppetlabs.trapperkeeper.services.protocols.metrics :as metrics]
             [puppetlabs.i18n.core :as i18n]
             [clojure.tools.logging :as log]
             [clojure.string :as str])
   (:import (com.puppetlabs.puppetserver PuppetProfiler JRubyPuppet)
            (clojure.lang IFn)
-           (java.util HashMap)))
+           (java.util HashMap)
+           (com.codahale.metrics MetricRegistry)
+           (org.jruby.runtime Constants)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Constants
@@ -29,7 +32,14 @@
   classpath.
 
   See also:  http://jruby.org/apidocs/org/jruby/runtime/load/LoadService.html"
-  "puppetserver-lib")
+  ;; Under JRuby 9k (and presumably later JRuby versions as well), JRuby
+  ;; will fail to find resources from the classpath unless they are prefixed
+  ;; with "classpath:/".  JRuby 1.x will generally find resources when
+  ;; prefixed with "classpath:/" as well, but an invocation of JRuby's irb
+  ;; will error out with "java.lang.NullPointerException: 'in' is null"
+  ;; when the "classpath:/" prefix is included.  The code below ensures
+  ;; that the "classpath:/" prefix is only included for JRuby 9k.
+  (str (if jruby-schemas/using-jruby-9k? "classpath:/") "puppetserver-lib"))
 
 (def default-http-connect-timeout
   "The default number of milliseconds that the client will wait for a connection
@@ -41,6 +51,10 @@
   be available on the socket. Currently set to 20 minutes."
   (* 20 60 1000))
 
+(def default-http-metrics-enabled
+  "The default for whether or not to enable http client metrics. Currently set to true."
+  true)
+
 (def default-master-conf-dir
   "/etc/puppetlabs/puppet")
 
@@ -89,6 +103,10 @@
   "Well-known name of the facter jar file"
   "facter.jar")
 
+(def MetricsInfo
+  {:metric-registry MetricRegistry
+   :server-id schema/Str})
+
 (schema/defn ^:always-validate
   add-facter-jar-to-system-classloader!
   "Searches the ruby load path for a file whose name matches that of the
@@ -106,12 +124,14 @@
 
 (schema/defn get-initialize-pool-instance-fn :- IFn
   [config :- jruby-puppet-schemas/JRubyPuppetConfig
-   profiler :- (schema/maybe PuppetProfiler)]
+   profiler :- (schema/maybe PuppetProfiler)
+   metrics-service]
   (fn [jruby-instance]
     (let [{:keys [http-client-ssl-protocols
                   http-client-cipher-suites
                   http-client-connect-timeout-milliseconds
                   http-client-idle-timeout-milliseconds
+                  http-client-metrics-enabled
                   use-legacy-auth-conf]} config
           scripting-container (:scripting-container jruby-instance)]
 
@@ -124,6 +144,10 @@
           (.put puppetserver-config "ssl_protocols" (into-array String http-client-ssl-protocols)))
         (when http-client-cipher-suites
           (.put puppetserver-config "cipher_suites" (into-array String http-client-cipher-suites)))
+        (when http-client-metrics-enabled
+          (doto puppetserver-config
+            (.put "metric_registry" (metrics/get-metrics-registry metrics-service :puppetserver))
+            (.put "server_id" (metrics/get-server-id metrics-service))))
         (doto puppetserver-config
           (.put "profiler" profiler)
           (.put "environment_registry" env-registry)
@@ -160,7 +184,8 @@
   (select-keys config [:ssl-protocols
                        :cipher-suites
                        :connect-timeout-milliseconds
-                       :idle-timeout-milliseconds]))
+                       :idle-timeout-milliseconds
+                       :metrics-enabled]))
 
 (schema/defn ^:always-validate initialize-gem-path
   [{:keys [gem-home gem-path] :as jruby-config} :- {schema/Keyword schema/Any}]
@@ -181,13 +206,15 @@
       (assoc :http-client-idle-timeout-milliseconds
              (get http-config :idle-timeout-milliseconds
                   default-http-socket-timeout))
+      (assoc :http-client-metrics-enabled
+             (get http-config :metrics-enabled default-http-metrics-enabled))
       (update-in [:master-conf-dir] #(or % default-master-conf-dir))
       (update-in [:master-var-dir] #(or % default-master-var-dir))
       (update-in [:master-code-dir] #(or % default-master-code-dir))
       (update-in [:master-run-dir] #(or % default-master-run-dir))
       (update-in [:master-log-dir] #(or % default-master-log-dir))
       (update-in [:max-requests-per-instance] #(or % 0))
-      (update-in [:use-legacy-auth-conf] #(or % (nil? %)))
+      (update-in [:use-legacy-auth-conf] #(if (some? %) % false))
       (dissoc :environment-class-cache-enabled)))
 
 (schema/defn create-jruby-config :- jruby-schemas/JRubyConfig
@@ -199,8 +226,9 @@
   [jruby-puppet-config :- jruby-puppet-schemas/JRubyPuppetConfig
    jruby-config :- {schema/Keyword schema/Any}
    agent-shutdown-fn :- IFn
-   profiler :- (schema/maybe PuppetProfiler)]
-  (let [initialize-pool-instance-fn (get-initialize-pool-instance-fn jruby-puppet-config profiler)
+   profiler :- (schema/maybe PuppetProfiler)
+   metrics-service]
+  (let [initialize-pool-instance-fn (get-initialize-pool-instance-fn jruby-puppet-config profiler metrics-service)
         lifecycle-fns {:shutdown-on-error agent-shutdown-fn
                        :initialize-pool-instance initialize-pool-instance-fn
                        :cleanup cleanup-fn}
@@ -224,19 +252,29 @@
   This arity is intended for uses where a jruby-config is required but will not be used
   to create a pool, such as the cli ruby subcommands
 
-  The 4-arity function takes a profiler object which will be placed into the puppetserver
-  config through the :initialize-pool-instance lifecycle function. The agent-shutdown-fn
-  is run when a jruby-instance is terminated. When warn-legacy-auth-conf? is passed in as
-  true, it will log a warning that the use-legacy-auth-conf setting is deprecated if the
-  config setting is set to true as well."
+  The 5-arity function takes a profiler object and the metrics service. The profiler is placed into
+  the puppetserver config through the :initialize-pool-instance lifecycle function. If the
+  `http-client -> metrics-enabled` setting is set to true, then the metrics service is used to get a
+  metrics registry for the `:puppetserver` domain, and the server id - these are also placed into
+  the puppetserver config. The agent-shutdown-fn is run when a jruby-instance is terminated. When
+  warn-legacy-auth-conf? is passed in as true, it will log a warning that the use-legacy-auth-conf
+  setting is deprecated if the config setting is set to true as well."
   ([raw-config :- {:jruby-puppet {schema/Keyword schema/Any}
                    (schema/optional-key :http-client) {schema/Keyword schema/Any}
                    schema/Keyword schema/Any}]
-   (initialize-and-create-jruby-config raw-config nil (fn []) false))
+   (initialize-and-create-jruby-config raw-config nil (fn []) false nil))
   ([raw-config :- {schema/Keyword schema/Any}
     profiler :- (schema/maybe PuppetProfiler)
     agent-shutdown-fn :- IFn
-    warn-legacy-auth-conf? :- schema/Bool]
+    warn-legacy-auth-conf? :- schema/Bool
+    metrics-service]
+   (when (get-in raw-config [:jruby-puppet :compat-version])
+     (log/errorf "%s %s %s"
+                 (i18n/trs "The jruby-puppet.compat-version setting is no longer supported.")
+                 (i18n/trs "To use Ruby language version 1.9.3, remove the jruby-puppet.compat-version setting.")
+                 (i18n/trs "To use a Ruby language version later than 2.0, remove the jruby-puppet.compat-version setting and add the line 'JRUBY_JAR=/opt/puppetlabs/server/apps/puppetserver/jruby-9k.jar' to the /etc/sysconfig/(pe-)puppet(-)server or /etc/default/(pe-)puppet(-)server file."))
+     (throw (IllegalArgumentException.
+             (i18n/trs "jruby-puppet.compat-version setting no longer supported"))))
    (let [jruby-puppet-config (initialize-puppet-config
                               (extract-http-config (:http-client raw-config))
                               (extract-puppet-config (:jruby-puppet raw-config)))
@@ -249,7 +287,7 @@
         (i18n/trs "The 'jruby-puppet.use-legacy-auth-conf' setting is set to ''true''.")
         (i18n/trs "Support for the legacy Puppet auth.conf file is deprecated and will be removed in a future release.")
         (i18n/trs "Change this setting to 'false' and migrate your authorization rule definitions in the /etc/puppetlabs/puppet/auth.conf file to the /etc/puppetlabs/puppetserver/conf.d/auth.conf file.")))
-     (create-jruby-config jruby-puppet-config uninitialized-jruby-config agent-shutdown-fn profiler))))
+     (create-jruby-config jruby-puppet-config uninitialized-jruby-config agent-shutdown-fn profiler metrics-service))))
 
 (def EnvironmentClassInfoCacheEntry
   "Data structure that holds per-environment cache information for the
