@@ -5,7 +5,8 @@
             [puppetlabs.trapperkeeper.core :as trapperkeeper]
             [puppetlabs.trapperkeeper.services :as tk-services]
             [puppetlabs.services.protocols.jruby-puppet :as jruby]
-            [puppetlabs.i18n.core :as i18n]))
+            [puppetlabs.i18n.core :as i18n])
+  (:import (org.jruby.runtime Constants)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Public
@@ -18,17 +19,24 @@
                           [[:ConfigService get-config]
                            [:ShutdownService shutdown-on-error]
                            [:PuppetProfilerService get-profiler]
-                           [:PoolManagerService create-pool]]
+                           [:PoolManagerService create-pool]
+                           MetricsService]
+
   (init
     [this context]
     (log/info (i18n/trs "Initializing the JRuby service"))
-    (let [jruby-config (core/initialize-and-create-jruby-config
-                        (get-config)
+    (let [config (get-config)
+          metrics-service (tk-services/get-service this :MetricsService)
+          jruby-config (core/initialize-and-create-jruby-config
+                        config
                         (get-profiler)
                         (partial shutdown-on-error (tk-services/service-id this))
-                        true)
+                        true
+                        metrics-service)
           _ (core/add-facter-jar-to-system-classloader! (:ruby-load-path jruby-config))
           pool-context (create-pool jruby-config)]
+      (log/info (i18n/trs "JRuby version info: {0}"
+                          jruby-core/jruby-version-info))
       (-> context
           (assoc :pool-context pool-context)
           (assoc :environment-class-info-tags (atom {})))))
@@ -36,7 +44,12 @@
   (stop
    [this context]
    (let [{:keys [pool-context]} (tk-services/service-context this)]
-     (jruby-core/flush-pool-for-shutdown! pool-context))
+     ;; Only flush the pool if there is a pool-context available.  No pool-context
+     ;; would be available if an exception were to be thrown during service
+     ;; initialization before the pool-context were created - e.g., during the
+     ;; the initialization of an upstream service.
+     (when pool-context
+       (jruby-core/flush-pool-for-shutdown! pool-context)))
    context)
 
   (free-instance-count
@@ -64,6 +77,14 @@
     [this jruby-instance env-name]
     (.getClassInfoForEnvironment jruby-instance env-name))
 
+  (get-environment-module-info
+    [this jruby-instance env-name]
+    (.getModuleInfoForEnvironment jruby-instance env-name))
+
+  (get-all-environment-module-info
+    [this jruby-instance]
+    (.getModuleInfoForAllEnvironments jruby-instance))
+
   (get-environment-class-info-tag
    [this env-name]
    (let [environment-class-info (:environment-class-info-tags
