@@ -1,7 +1,8 @@
 (ns puppetlabs.services.jruby-pool-manager.impl.jruby-internal
   (:require [schema.core :as schema]
             [puppetlabs.services.jruby-pool-manager.jruby-schemas :as jruby-schemas]
-            [clojure.tools.logging :as log])
+            [clojure.tools.logging :as log]
+            [puppetlabs.i18n.core :as i18n])
   (:import (com.puppetlabs.jruby_utils.pool JRubyPool)
            (puppetlabs.services.jruby_pool_manager.jruby_schemas JRubyInstance PoisonPill
                                                                  ShutdownPoisonPill)
@@ -9,11 +10,19 @@
            (org.jruby.embed LocalContextScope)
            (java.util.concurrent TimeUnit)
            (clojure.lang IFn)
-           (com.puppetlabs.jruby_utils.jruby ScriptingContainer)))
+           (com.puppetlabs.jruby_utils.jruby InternalScriptingContainer
+                                             ScriptingContainer)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Private
 
+(def default-jruby-1-7-compat-version
+  "Default value for JRuby's 'CompatVersion' setting.  This value is only
+  meaningful for JRuby 1.7.  For JRuby 9k, this will return `nil` because
+  JRuby 9k effectively doesn't support configurable language compatibility
+  versions."
+  (when-not jruby-schemas/using-jruby-9k? CompatVersion/RUBY1_9))
+
 (schema/defn ^:always-validate initialize-gem-path :- {schema/Keyword schema/Any}
   [{:keys [gem-path gem-home] :as jruby-config} :- {schema/Keyword schema/Any}]
   (if gem-path
@@ -33,34 +42,24 @@
     :force RubyInstanceConfig$CompileMode/FORCE
     :off RubyInstanceConfig$CompileMode/OFF))
 
-(schema/defn ^:always-validate get-compat-version
-  "Get the JRuby compatibility version to use for all ruby components, e.g. the
-  master service and CLI tools."
-  [compat-version :- jruby-schemas/SupportedJRubyCompatVersions]
-  (case compat-version
-    "1.9" (CompatVersion/RUBY1_9)
-    "2.0" (CompatVersion/RUBY2_0)
-    (throw (IllegalArgumentException.
-            (format (str "compat-version is set to `%s`, which is not an allowed option."
-                         " The available compat-versions are `1.9` and `2.0`") compat-version)))))
-
 (schema/defn ^:always-validate init-jruby :- jruby-schemas/ConfigurableJRuby
   "Applies configuration to a JRuby... thing.  See comments in `ConfigurableJRuby`
   schema for more details."
   [jruby :- jruby-schemas/ConfigurableJRuby
    config :- jruby-schemas/JRubyConfig]
-  (let [{:keys [ruby-load-path compile-mode lifecycle compat-version]} config
+  (let [{:keys [ruby-load-path compile-mode lifecycle]} config
         initialize-scripting-container-fn (:initialize-scripting-container lifecycle)]
     (doto jruby
       (.setLoadPaths ruby-load-path)
-      (.setCompatVersion (get-compat-version compat-version))
       (.setCompileMode (get-compile-mode compile-mode)))
+    (when-let [compat-version default-jruby-1-7-compat-version]
+      (.setCompatVersion jruby compat-version))
     (initialize-scripting-container-fn jruby config)))
 
 (schema/defn ^:always-validate empty-scripting-container :- ScriptingContainer
   "Creates a clean instance of a JRuby `ScriptingContainer` with no code loaded."
   [config :- jruby-schemas/JRubyConfig]
-  (-> (ScriptingContainer. LocalContextScope/SINGLETHREAD)
+  (-> (InternalScriptingContainer. LocalContextScope/SINGLETHREAD)
       (init-jruby config)))
 
 (schema/defn ^:always-validate create-scripting-container :- ScriptingContainer
@@ -85,6 +84,15 @@
    pool :- jruby-schemas/pool-queue-type]
   (.borrowItemWithTimeout pool timeout TimeUnit/MILLISECONDS))
 
+(schema/defn insert-shutdown-poison-pill
+  [pool :- jruby-schemas/pool-queue-type]
+  (.insertPill pool (ShutdownPoisonPill. pool)))
+
+(schema/defn insert-poison-pill
+  [pool :- jruby-schemas/pool-queue-type
+   error :- Throwable]
+  (.insertPill pool (PoisonPill. error)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Public
 
@@ -104,7 +112,8 @@
     (.unregister pool instance)
     (cleanup-fn instance)
     (.terminate scripting-container)
-    (log/infof "Cleaned up old JRubyInstance with id %s." (:id instance))))
+    (log/infof (i18n/trs "Cleaned up old JRubyInstance with id {0}."
+                         (:id instance)))))
 
 (schema/defn ^:always-validate
   create-pool-instance! :- JRubyInstance
@@ -117,8 +126,8 @@
         initialize-pool-instance-fn (:initialize-pool-instance lifecycle)]
     (when-not ruby-load-path
       (throw (Exception.
-               "JRuby service missing config value 'ruby-load-path'")))
-    (log/infof "Creating JRubyInstance with id %s." id)
+              (i18n/trs "JRuby service missing config value 'ruby-load-path'"))))
+    (log/infof (i18n/trs "Creating JRubyInstance with id {0}." id))
     (let [scripting-container (create-scripting-container
                                config)]
       (let [instance (jruby-schemas/map->JRubyInstance
@@ -156,6 +165,12 @@
   [context :- jruby-schemas/PoolContext]
   (get-in context [:config :max-active-instances]))
 
+(schema/defn ^:always-validate
+  get-flush-timeout :- schema/Int
+  "Gets the size of the JRuby pool from the pool context."
+  [context :- jruby-schemas/PoolContext]
+  (get-in context [:config :flush-timeout]))
+
 (schema/defn ^:always-validate
   get-instance-state-container :- jruby-schemas/JRubyInstanceStateContainer
   "Gets the InstanceStateContainer (atom) from the instance."
@@ -178,21 +193,22 @@
           (do
             (.releaseItem pool instance)
             (throw (IllegalStateException.
-                     "Unable to borrow JRubyInstance from pool"
-                     (:err instance))))
+                    (i18n/tru "Unable to borrow JRubyInstance from pool")
+                    (:err instance))))
 
           (jruby-schemas/jruby-instance? instance)
           instance
 
-          ((some-fn nil? jruby-schemas/retry-poison-pill?) instance)
+          (jruby-schemas/shutdown-poison-pill? instance)
           instance
 
-          (instance? ShutdownPoisonPill instance)
+          (nil? instance)
           instance
 
           :else
           (throw (IllegalStateException.
-                   (str "Borrowed unrecognized object from pool!: " instance))))))
+                  (i18n/tru "Borrowed unrecognized object from pool!: {0}"
+                            instance))))))
 
 (schema/defn ^:always-validate
   borrow-from-pool :- jruby-schemas/JRubyInstanceOrPill
@@ -218,27 +234,24 @@
 
 (schema/defn ^:always-validate
   return-to-pool
-  "Return a borrowed pool instance to its free pool."
+  "Return a borrowed pool instance to its free pool.
+  Also check if the borrow count has exceeded, and flush it if needed.
+  If the instance is not a JRubyInstance, it must be a poison pill, in
+  which case this function is a noop"
   [instance :- jruby-schemas/JRubyInstanceOrPill]
-  (if (jruby-schemas/jruby-instance? instance)
+  (when (jruby-schemas/jruby-instance? instance)
     (let [new-state (swap! (get-instance-state-container instance)
                            update-in [:borrow-count] inc)
           {:keys [max-borrows flush-instance-fn pool]} (:internal instance)]
       (if (and (pos? max-borrows)
                (>= (:borrow-count new-state) max-borrows))
         (do
-          (log/infof (str "Flushing JRubyInstance %s because it has exceeded the "
-                          "maximum number of borrows (%s)")
+          (log/infof
+           (i18n/trs "Flushing JRubyInstance {0} because it has exceeded the maximum number of borrows ({1})"
                      (:id instance)
-                     max-borrows)
-          (try
-            (flush-instance-fn pool instance)
-            (finally
-              (.releaseItem pool instance false))))
-        (.releaseItem pool instance)))
-    ;; if we get here, it was from a borrow and we got a Retry, so we just
-    ;; return it to the pool.
-    (.releaseItem (:pool instance) instance)))
+                     max-borrows))
+          (flush-instance-fn instance))
+        (.releaseItem pool instance)))))
 
 (schema/defn ^:always-validate new-main :- jruby-schemas/JRubyMain
   "Return a new JRubyMain instance which should only be used for CLI purposes,
