@@ -1,9 +1,10 @@
 (ns puppetlabs.services.master.master-core
   (:import (java.io FileInputStream)
            (clojure.lang IFn)
-           (java.util Map Map$Entry)
+           (java.util List Map Map$Entry)
            (org.jruby RubySymbol)
-           (org.eclipse.jetty.util URIUtil))
+           (com.codahale.metrics MetricRegistry Gauge)
+           (java.lang.management ManagementFactory))
   (:require [me.raynes.fs :as fs]
             [puppetlabs.puppetserver.ringutils :as ringutils]
             [puppetlabs.puppetserver.common :as ps-common]
@@ -19,7 +20,12 @@
             [clojure.string :as str]
             [bidi.schema :as bidi-schema]
             [ring.middleware.params :as ring]
-            [puppetlabs.i18n.core :as i18n]))
+            [puppetlabs.i18n.core :as i18n]
+            [puppetlabs.metrics :as metrics]
+            [puppetlabs.metrics.http :as http-metrics]
+            [puppetlabs.http.client.metrics :as http-client-metrics]
+            [puppetlabs.http.client.common :as http-client-common]
+            [puppetlabs.trapperkeeper.services.status.status-core :as status-core]))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Constants
@@ -124,6 +130,17 @@
   {:name schema/Str
    :files [EnvironmentClassesFileEntry]})
 
+(def EnvironmentModuleInfo
+  "Schema for a given module that can be returned within the
+  :modules key in EnvironmentModulesInfo."
+  {:name schema/Str
+   :version (schema/maybe schema/Str)})
+
+(def EnvironmentModulesInfo
+  "Schema for the return payload for an environment_classes request."
+  {:name schema/Str
+   :modules [EnvironmentModuleInfo]})
+
 (defn obj-or-ruby-symbol-as-string
   "If the supplied object is of type RubySymbol, returns a string
   representation of the RubySymbol.  Otherwise, just returns the original
@@ -142,7 +159,7 @@
     (throw (IllegalArgumentException.
             (i18n/trs "Object cannot be coerced to a keyword: {0}" obj)))))
 
-(defn sort-nested-environment-class-info-maps
+(defn sort-nested-info-maps
   "For a data structure, recursively sort any nested maps and sets descending
   into map values, lists, vectors and set members as well. The result should be
   that all maps in the data structure become explicitly sorted with natural
@@ -171,10 +188,10 @@
     (instance? Map data)
     (into (sorted-map) (for [[k v] data]
                          [(obj->keyword k)
-                          (sort-nested-environment-class-info-maps v)]))
+                          (sort-nested-info-maps v)]))
 
     (instance? Iterable data)
-    (map sort-nested-environment-class-info-maps data)
+    (map sort-nested-info-maps data)
 
     :else data))
 
@@ -219,7 +236,7 @@
   (-> file-info
       val
       (add-path-to-file-entry (key file-info))
-      sort-nested-environment-class-info-maps))
+      sort-nested-info-maps))
 
 (schema/defn ^:always-validate
   class-info-from-jruby->class-info-for-json :- EnvironmentClassesInfo
@@ -326,6 +343,53 @@
                                      environment-class-cache-enabled)
         (rr/not-found (i18n/tru "Could not find environment ''{0}''" environment))))))
 
+(schema/defn ^:always-validate
+  module-info-from-jruby->module-info-for-json  :- EnvironmentModulesInfo
+  "Creates a new map with a top level key `name` that corresponds to the
+  requested environment and a top level key `modules` which contains the module
+  information obtained from JRuby."
+  [info-from-jruby :- List
+   environment :- schema/Str]
+  (->> info-from-jruby
+       sort-nested-info-maps
+       vec
+       (sorted-map :name environment :modules)))
+
+(schema/defn ^:always-validate
+  environment-module-response! :- ringutils/RingResponse
+  "Process the environment module information, returning a ring response to be
+  propagated back up to the caller of the environment_modules endpoint."
+  ([info-from-jruby :- Map]
+   (let [all-info-as-json (map #(module-info-from-jruby->module-info-for-json
+                                  (val %)
+                                  (name (key %)))
+                               (sort-nested-info-maps info-from-jruby))]
+     (middleware-utils/json-response 200 all-info-as-json)))
+  ([info-from-jruby :- List
+    environment :- schema/Str]
+   (let [info-as-json (module-info-from-jruby->module-info-for-json
+                        info-from-jruby environment)]
+     (middleware-utils/json-response 200 info-as-json))))
+
+(schema/defn ^:always-validate
+  environment-module-info-fn :- IFn
+  "Middleware function for constructing a Ring response from an incoming
+  request for environment_modules information."
+  [jruby-service :- (schema/protocol jruby-protocol/JRubyPuppetService)]
+  (fn [request]
+    (if-let [environment (jruby-request/get-environment-from-request request)]
+      (if-let [module-info
+               (jruby-protocol/get-environment-module-info jruby-service
+                                                           (:jruby-instance request)
+                                                           environment)]
+        (environment-module-response! module-info
+                                      environment)
+        (rr/not-found (i18n/tru "Could not find environment ''{0}''" environment)))
+      (let [module-info
+            (jruby-protocol/get-all-environment-module-info jruby-service
+                                                            (:jruby-instance request))]
+        (environment-module-response! module-info)))))
+
 (schema/defn ^:always-validate
   wrap-with-etag-check :- IFn
   "Middleware function which validates whether or not the If-None-Match
@@ -360,6 +424,17 @@
    jruby-request/wrap-with-environment-validation
    jruby-request/wrap-with-error-handling))
 
+
+(schema/defn ^:always-validate
+  environment-module-handler :- IFn
+  "Handler for processing an incoming environment_modules Ring request"
+  [jruby-service :- (schema/protocol jruby-protocol/JRubyPuppetService)]
+  (->
+   (environment-module-info-fn jruby-service)
+   (jruby-request/wrap-with-jruby-instance jruby-service)
+   (jruby-request/wrap-with-environment-validation true)
+   jruby-request/wrap-with-error-handling))
+
 (schema/defn ^:always-validate valid-static-file-path?
   "Helper function to decide if a static_file_content path is valid.
   The access here is designed to mimic Puppet's file_content endpoint."
@@ -382,23 +457,41 @@
       (cond
         (some empty? [environment code-id file-path])
         {:status 400
+         :headers {"Content-Type" "text/plain"}
          :body (i18n/tru "Error: A /static_file_content request requires an environment, a code-id, and a file-path")}
+
         (not (nil? (schema/check ps-common/Environment environment)))
         {:status 400
+         :headers {"Content-Type" "text/plain"}
          :body (ps-common/environment-validation-error-msg environment)}
 
         (not (nil? (schema/check ps-common/CodeId code-id)))
         {:status 400
+         :headers {"Content-Type" "text/plain"}
          :body (ps-common/code-id-validation-error-msg code-id)}
 
         (not (valid-static-file-path? file-path))
         {:status 403
+         :headers {"Content-Type" "text/plain"}
          :body (i18n/tru "Request Denied: A /static_file_content request must be a file within the files directory of a module.")}
 
         :else
         {:status 200
+         :headers {"Content-Type" "application/octet-stream"}
          :body (get-code-content environment code-id file-path)}))))
 
+(def MetricIdsForStatus (schema/atom [[schema/Str]]))
+
+(schema/defn http-client-metrics-summary
+  :- {:metrics-data [http-client-common/MetricIdMetricData]
+      :sorted-metrics-data [http-client-common/MetricIdMetricData]}
+  [metric-registry :- MetricRegistry
+   metric-ids-to-select :- MetricIdsForStatus]
+  (let [metrics-data (map #(http-client-metrics/get-client-metrics-data-by-metric-id metric-registry %)
+                          @metric-ids-to-select)
+        flattened-data (flatten metrics-data)]
+    {:metrics-data flattened-data
+     :sorted-metrics-data (sort-by :aggregate > flattened-data)}))
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Routing
 
@@ -428,10 +521,6 @@
                 (request-handler (assoc request :include-code-id? true)))
    (comidi/PUT ["/report/" [#".*" :rest]] request
                (request-handler request))
-   (comidi/GET ["/resource_type/" [#".*" :rest]] request
-               (request-handler request))
-   (comidi/GET ["/resource_types/" [#".*" :rest]] request
-               (request-handler request))
    (comidi/GET ["/environment/" [#".*" :environment]] request
                (request-handler (assoc request :include-code-id? true)))
    (comidi/GET "/environments" request
@@ -448,13 +537,17 @@
   (let [environment-class-handler
         (environment-class-handler jruby-service
                                    environment-class-cache-enabled)
+        environment-module-handler
+        (environment-module-handler jruby-service)
         static-file-content-handler
         (static-file-content-request-handler get-code-content-fn)]
     (comidi/routes
-     (comidi/GET ["/environment_classes" [#".*" :rest]] request
-                 (environment-class-handler request))
-     (comidi/GET ["/static_file_content/" [#".*" :rest]] request
-                 (static-file-content-handler request)))))
+      (comidi/GET ["/environment_classes" [#".*" :rest]] request
+                  (environment-class-handler request))
+      (comidi/GET ["/environment_modules" [#".*" :rest]] request
+                  (environment-module-handler request))
+      (comidi/GET ["/static_file_content/" [#".*" :rest]] request
+                  (static-file-content-handler request)))))
 
 (schema/defn ^:always-validate
   v3-routes :- bidi-schema/RoutePair
@@ -511,6 +604,55 @@
                         (i18n/trs "Puppet Server requires at least {0}MB of available RAM given this heap size, computed as 1.1 * max heap (-Xmx)." (int (/ required-mem-size 1024.0)))
                         (i18n/trs "Either increase available memory or decrease the configured heap size by reducing the -Xms and -Xmx values in JAVA_ARGS in /etc/sysconfig/puppetserver on EL systems or /etc/default/puppetserver on Debian systems."))))))))
 
+(defn register-gauge!
+  [registry hostname metric-name metric-fn]
+  (.register registry (metrics/host-metric-name hostname metric-name)
+             (proxy [Gauge] []
+               (getValue []
+                 (metric-fn)))))
+
+(schema/defn register-jvm-metrics!
+  [registry :- MetricRegistry
+   hostname :- schema/Str]
+  (register-gauge! registry hostname "uptime"
+                   (fn [] (.getUptime (ManagementFactory/getRuntimeMXBean))))
+  (let [memory-mbean (ManagementFactory/getMemoryMXBean)
+        get-heap-memory (fn [] (.getHeapMemoryUsage memory-mbean))
+        get-non-heap-memory (fn [] (.getNonHeapMemoryUsage memory-mbean))]
+    (register-gauge! registry hostname "memory.heap.committed"
+                     (fn [] (.getCommitted (get-heap-memory))))
+    (register-gauge! registry hostname "memory.heap.init"
+                     (fn [] (.getInit (get-heap-memory))))
+    (register-gauge! registry hostname "memory.heap.max"
+                     (fn [] (.getMax (get-heap-memory))))
+    (register-gauge! registry hostname "memory.heap.used"
+                     (fn [] (.getUsed (get-heap-memory))))
+
+    (register-gauge! registry hostname "memory.non-heap.committed"
+                     (fn [] (.getCommitted (get-non-heap-memory))))
+    (register-gauge! registry hostname "memory.non-heap.init"
+                     (fn [] (.getInit (get-non-heap-memory))))
+    (register-gauge! registry hostname "memory.non-heap.max"
+                     (fn [] (.getMax (get-non-heap-memory))))
+    (register-gauge! registry hostname "memory.non-heap.used"
+                     (fn [] (.getUsed (get-non-heap-memory))))
+
+    ;; Unfortunately there isn't an mbean for "total" memory. Dropwizard metrics'
+    ;; MetricUsageGaugeSet has "total" metrics that are computed by adding together Heap Memory and
+    ;; Non Heap Memory.
+    (register-gauge! registry hostname "memory.total.committed"
+                     (fn [] (+ (.getCommitted (get-heap-memory))
+                               (.getCommitted (get-non-heap-memory)))))
+    (register-gauge! registry hostname "memory.total.init"
+                     (fn [] (+ (.getInit (get-heap-memory))
+                               (.getInit (get-non-heap-memory)))))
+    (register-gauge! registry hostname "memory.total.max"
+                     (fn [] (+ (.getMax (get-heap-memory))
+                               (.getMax (get-non-heap-memory)))))
+    (register-gauge! registry hostname "memory.total.used"
+                     (fn [] (+ (.getUsed (get-heap-memory))
+                               (.getUsed (get-non-heap-memory)))))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Public
 
@@ -613,3 +755,62 @@
                  jruby-service
                  get-code-content
                  environment-class-cache-enabled)))
+
+(def MasterStatusV1
+  {(schema/optional-key :experimental) {:http-metrics [http-metrics/RouteSummary]
+                                        :http-client-metrics [http-client-common/MetricIdMetricData]}})
+
+(def puppet-server-http-client-metrics-for-status
+  [["puppet" "report" "http"]
+   ["puppetdb" "command" "replace_catalog"]
+   ["puppetdb" "command" "replace_facts"]
+   ["puppetdb" "command" "store_report"]
+   ["puppetdb" "facts" "find"]
+   ["puppetdb" "facts" "search"]
+   ["puppetdb" "query"]
+   ["puppetdb" "resource" "search"]])
+
+(schema/defn ^:always-validate add-metric-ids-to-http-client-metrics-list!
+  [metric-id-atom :- MetricIdsForStatus
+   metric-ids-to-add :- [[schema/Str]]]
+  (swap! metric-id-atom concat metric-ids-to-add))
+
+(schema/defn ^:always-validate v1-status :- status-core/StatusCallbackResponse
+  [http-metrics :- http-metrics/HttpMetrics
+   http-client-metric-ids-for-status :- MetricIdsForStatus
+   metric-registry :- MetricRegistry
+   level :- status-core/ServiceStatusDetailLevel]
+  (let [level>= (partial status-core/compare-levels >= level)]
+    {:state :running
+     :status (cond->
+              ;; no status info at ':critical' level
+              {}
+              ;; no extra status at ':info' level yet
+              (level>= :info) identity
+              (level>= :debug) (-> (assoc-in [:experimental :http-metrics]
+                                             (:sorted-routes
+                                              (http-metrics/request-summary http-metrics)))
+                                   (assoc-in [:experimental :http-client-metrics]
+                                             (:sorted-metrics-data
+                                              (http-client-metrics-summary
+                                               metric-registry
+                                               http-client-metric-ids-for-status)))))}))
+
+(def resources-root "puppetlabs/puppetserver/public")
+(def js-resources-root (str resources-root "/js"))
+
+(schema/defn ^:always-validate experimental-routes :- bidi-schema/RoutePair
+  [path]
+  (let [experimental (str path "/experimental")]
+    (comidi/context "/experimental"
+      (comidi/GET "" request
+                  (rr/redirect (str experimental "/dashboard.html")))
+      (comidi/GET "/" request
+                  (rr/redirect (str experimental "/dashboard.html")))
+      (comidi/GET "/dashboard.html" request
+                  (rr/resource-response "dashboard.html" {:root resources-root}))
+
+      ;; These calls create routes that are necessary in order for the
+      ;; javascript code to retrieve resources from inside the jar
+      (comidi/resources "/metrics-dashboard" {:root "puppetlabs/metrics/dashboard/public"})
+      (comidi/resources "/js" {:root js-resources-root}))))
