@@ -17,7 +17,7 @@
  * @fileoverview A class representing a set of test functions that use
  * asynchronous functions that cannot be meaningfully mocked.
  *
- * To create a Google-compatable JsUnit test using this test case, put the
+ * To create a Google-compatible JsUnit test using this test case, put the
  * following snippet in your test:
  *
  *   var asyncTestCase = goog.testing.AsyncTestCase.createAndInstall();
@@ -111,13 +111,12 @@ goog.provide('goog.testing.AsyncTestCase');
 goog.provide('goog.testing.AsyncTestCase.ControlBreakingException');
 
 goog.require('goog.testing.TestCase');
-goog.require('goog.testing.TestCase.Test');
 goog.require('goog.testing.asserts');
 
 
 
 /**
- * A test case that is capable of running tests the contain asynchronous logic.
+ * A test case that is capable of running tests that contain asynchronous logic.
  * @param {string=} opt_name A descriptive name for the test case.
  * @extends {goog.testing.TestCase}
  * @constructor
@@ -141,15 +140,20 @@ goog.testing.AsyncTestCase.TopStackFuncResult_;
  * An exception class used solely for control flow.
  * @param {string=} opt_message Error message.
  * @constructor
+ * @extends {Error}
  * @final
  */
 goog.testing.AsyncTestCase.ControlBreakingException = function(opt_message) {
+  goog.testing.AsyncTestCase.ControlBreakingException.base(
+      this, 'constructor', opt_message);
+
   /**
    * The exception message.
    * @type {string}
    */
   this.message = opt_message || '';
 };
+goog.inherits(goog.testing.AsyncTestCase.ControlBreakingException, Error);
 
 
 /**
