@@ -93,7 +93,7 @@ goog.testing.MockClassRecord = function(namespace, className, originalClass,
   /**
    * A mocks that will be constructed by their argument list.  The entries are
    * objects with the format {'args': args, 'mock': mock}.
-   * @type {Array.<Object>}
+   * @type {Array<Object>}
    * @private
    */
   this.instancesByArgs_ = [];
@@ -167,7 +167,7 @@ goog.testing.MockClassRecord.prototype.setStaticMock = function(staticMock) {
 /**
  * Adds a new mock instance mapping.  The mapping connects a set of function
  * arguments to a specific mock instance.
- * @param {Array} args An array of function arguments.
+ * @param {Array<?>} args An array of function arguments.
  * @param {goog.testing.StrictMock|goog.testing.LooseMock} mock A mock
  *     associated with the supplied arguments.
  */
@@ -179,7 +179,7 @@ goog.testing.MockClassRecord.prototype.addMockInstance = function(args, mock) {
 /**
  * Finds the mock corresponding to a given argument set.  Throws an error if
  * there is no appropriate match found.
- * @param {Array} args An array of function arguments.
+ * @param {Array<?>} args An array of function arguments.
  * @return {goog.testing.StrictMock|goog.testing.LooseMock|null} The mock
  *     corresponding to a given argument set.
  */
@@ -239,7 +239,7 @@ goog.testing.MockClassFactory.instance_ = null;
 
 /**
  * The names of the fields that are defined on Object.prototype.
- * @type {Array.<string>}
+ * @type {Array<string>}
  * @private
  */
 goog.testing.MockClassFactory.PROTOTYPE_FIELDS_ = [
@@ -335,7 +335,7 @@ goog.testing.MockClassFactory.prototype.getProxyFunction_ = function(fnName) {
 /**
  * Find a mock instance for a given class name and argument list.
  * @param {string} className The name of the class.
- * @param {Array} args The argument list to match.
+ * @param {Array<?>} args The argument list to match.
  * @return {goog.testing.StrictMock|goog.testing.LooseMock} The mock found for
  *     the given argument list.
  * @private
@@ -362,7 +362,10 @@ goog.testing.MockClassFactory.prototype.createProxy_ = function(namespace,
   var proxy = this.getProxyCtor_(className,
       goog.bind(this.findMockInstance_, this));
   var protoToProxy = classToMock.prototype;
+  // Preserve base() call in mocked class
+  var classToMockBase = classToMock.base;
   goog.inherits(proxy, classToMock);
+  proxy.base = classToMockBase;
 
   for (var prop in protoToProxy) {
     if (goog.isFunction(protoToProxy[prop])) {
@@ -440,11 +443,11 @@ goog.testing.MockClassFactory.prototype.getMockClass_ =
  * @param {Function} classToMock The class that will be mocked.
  * @param {...*} var_args The arguments associated with this instance's
  *     constructor.
- * @return {goog.testing.StrictMock} The mock created for the provided class.
+ * @return {!goog.testing.StrictMock} The mock created for the provided class.
  */
 goog.testing.MockClassFactory.prototype.getStrictMockClass =
     function(namespace, classToMock, var_args) {
-  return /** @type {goog.testing.StrictMock} */ (this.getMockClass_(namespace,
+  return /** @type {!goog.testing.StrictMock} */ (this.getMockClass_(namespace,
       classToMock, true, arguments));
 };
 
