@@ -30,6 +30,7 @@ goog.require('goog.net.XhrIo');
 goog.require('goog.net.XmlHttp');
 goog.require('goog.object');
 goog.require('goog.structs.Map');
+goog.require('goog.uri.utils');
 
 
 
@@ -68,11 +69,18 @@ goog.inherits(goog.testing.net.XhrIo, goog.events.EventTarget);
 goog.testing.net.XhrIo.ResponseType = goog.net.XhrIo.ResponseType;
 
 
+/**
+ * The pattern matching the 'http' and 'https' URI schemes.
+ * @private {!RegExp}
+ */
+goog.testing.net.XhrIo.HTTP_SCHEME_PATTERN_ = /^https?$/i;
+
+
 /**
  * All non-disposed instances of goog.testing.net.XhrIo created
  * by {@link goog.testing.net.XhrIo.send} are in this Array.
  * @see goog.testing.net.XhrIo.cleanup
- * @type {Array.<goog.testing.net.XhrIo>}
+ * @type {!Array<!goog.testing.net.XhrIo>}
  * @private
  */
 goog.testing.net.XhrIo.sendInstances_ = [];
@@ -81,7 +89,8 @@ goog.testing.net.XhrIo.sendInstances_ = [];
 /**
  * Returns an Array containing all non-disposed instances of
  * goog.testing.net.XhrIo created by {@link goog.testing.net.XhrIo.send}.
- * @return {Array} Array of goog.testing.net.XhrIo instances.
+ * @return {!Array<!goog.testing.net.XhrIo>} Array of goog.testing.net.XhrIo
+ *     instances.
  */
 goog.testing.net.XhrIo.getSendInstances = function() {
   return goog.testing.net.XhrIo.sendInstances_;
@@ -112,10 +121,14 @@ goog.testing.net.XhrIo.cleanup = function() {
  *     request.
  * @param {number=} opt_timeoutInterval Number of milliseconds after which an
  *     incomplete request will be aborted; 0 means no timeout is set.
+ * @param {boolean=} opt_withCredentials Whether to send credentials with the
+ *     request. Default to false. See {@link goog.net.XhrIo#setWithCredentials}.
+ * @return {!goog.testing.net.XhrIo} The mocked sent XhrIo.
  */
 goog.testing.net.XhrIo.send = function(url, opt_callback, opt_method,
                                        opt_content, opt_headers,
-                                       opt_timeoutInterval) {
+                                       opt_timeoutInterval,
+                                       opt_withCredentials) {
   var x = new goog.testing.net.XhrIo();
   goog.testing.net.XhrIo.sendInstances_.push(x);
   if (opt_callback) {
@@ -127,7 +140,10 @@ goog.testing.net.XhrIo.send = function(url, opt_callback, opt_method,
   if (opt_timeoutInterval) {
     x.setTimeoutInterval(opt_timeoutInterval);
   }
+  x.setWithCredentials(Boolean(opt_withCredentials));
   x.send(url, opt_method, opt_content, opt_headers);
+
+  return x;
 };
 
 
@@ -135,7 +151,7 @@ goog.testing.net.XhrIo.send = function(url, opt_callback, opt_method,
  * Disposes of the specified goog.testing.net.XhrIo created by
  * {@link goog.testing.net.XhrIo.send} and removes it from
  * {@link goog.testing.net.XhrIo.pendingStaticSendInstances_}.
- * @param {goog.testing.net.XhrIo} XhrIo An XhrIo created by
+ * @param {!goog.testing.net.XhrIo} XhrIo An XhrIo created by
  *     {@link goog.testing.net.XhrIo.send}.
  * @private
  */
@@ -219,6 +235,14 @@ goog.testing.net.XhrIo.prototype.lastError_ = '';
 goog.testing.net.XhrIo.prototype.response_ = '';
 
 
+/**
+ * The status code.
+ * @type {number}
+ * @private
+ */
+goog.testing.net.XhrIo.prototype.statusCode_ = 0;
+
+
 /**
  * Mock ready state.
  * @type {number}
@@ -237,15 +261,6 @@ goog.testing.net.XhrIo.prototype.readyState_ =
 goog.testing.net.XhrIo.prototype.timeoutInterval_ = 0;
 
 
-/**
- * Window timeout ID used to cancel the timeout event handler if the request
- * completes successfully.
- * @type {Object}
- * @private
- */
-goog.testing.net.XhrIo.prototype.timeoutId_ = null;
-
-
 /**
  * The requested type for the response. The empty string means use the default
  * XHR behavior.
@@ -364,6 +379,7 @@ goog.testing.net.XhrIo.prototype.abort = function(opt_failureCode) {
   if (this.active_) {
     try {
       this.active_ = false;
+      this.statusCode_ = -1;
       this.lastErrorCode_ = opt_failureCode || goog.net.ErrorCode.ABORT;
       this.dispatchEvent(goog.net.EventType.COMPLETE);
       this.dispatchEvent(goog.net.EventType.ABORT);
@@ -518,15 +534,21 @@ goog.testing.net.XhrIo.prototype.isComplete = function() {
  * @return {boolean} Whether the request compeleted successfully.
  */
 goog.testing.net.XhrIo.prototype.isSuccess = function() {
-  switch (this.getStatus()) {
-    case goog.net.HttpStatus.OK:
-    case goog.net.HttpStatus.NO_CONTENT:
-    case goog.net.HttpStatus.NOT_MODIFIED:
-      return true;
+  var status = this.getStatus();
+  // A zero status code is considered successful for local files.
+  return goog.net.HttpStatus.isSuccess(status) ||
+      status === 0 && !this.isLastUriEffectiveSchemeHttp_();
+};
 
-    default:
-      return false;
-  }
+
+/**
+ * @return {boolean} whether the effective scheme of the last URI that was
+ *     fetched was 'http' or 'https'.
+ * @private
+ */
+goog.testing.net.XhrIo.prototype.isLastUriEffectiveSchemeHttp_ = function() {
+  var scheme = goog.uri.utils.getEffectiveScheme(String(this.lastUri_));
+  return goog.testing.net.XhrIo.HTTP_SCHEME_PATTERN_.test(scheme);
 };
 
 
@@ -727,7 +749,7 @@ goog.testing.net.XhrIo.prototype.getAllResponseHeaders = function() {
  * include any case normalization logic, it will just return a key-value
  * representation of the headers.
  * See: http://www.w3.org/TR/XMLHttpRequest/#the-getresponseheader()-method
- * @return {!Object.<string, string>} An object with the header keys as keys
+ * @return {!Object<string, string>} An object with the header keys as keys
  *     and header values as values.
  */
 goog.testing.net.XhrIo.prototype.getResponseHeaders = function() {
