@@ -26,6 +26,7 @@ goog.provide('goog.ui.Select');
 goog.require('goog.a11y.aria');
 goog.require('goog.a11y.aria.Role');
 goog.require('goog.a11y.aria.State');
+goog.require('goog.array');
 goog.require('goog.events.EventType');
 goog.require('goog.ui.Component');
 goog.require('goog.ui.IdGenerator');
@@ -51,7 +52,7 @@ goog.require('goog.ui.registry');
  * @param {goog.ui.Menu=} opt_menu Menu containing selection options.
  * @param {goog.ui.ButtonRenderer=} opt_renderer Renderer used to render or
  *     decorate the control; defaults to {@link goog.ui.MenuButtonRenderer}.
- * @param {goog.dom.DomHelper=} opt_domHelper Optional DOM hepler, used for
+ * @param {goog.dom.DomHelper=} opt_domHelper Optional DOM helper, used for
  *     document interaction.
  * @param {!goog.ui.MenuRenderer=} opt_menuRenderer Renderer used to render or
  *     decorate the menu; defaults to {@link goog.ui.MenuRenderer}.
@@ -146,7 +147,7 @@ goog.ui.Select.prototype.handleMenuAction = function(e) {
   this.setSelectedItem(/** @type {goog.ui.MenuItem} */ (e.target));
   goog.ui.Select.base(this, 'handleMenuAction', e);
 
-  // NOTE(user): We should not stop propagation and then fire
+  // NOTE(chrishenry): We should not stop propagation and then fire
   // our own ACTION event. Fixing this without breaking anyone
   // relying on this event is hard though.
   e.stopPropagation();
@@ -335,7 +336,7 @@ goog.ui.Select.prototype.setValue = function(value) {
     for (var i = 0, item; item = this.selectionModel_.getItemAt(i); i++) {
       if (item && typeof item.getValue == 'function' &&
           item.getValue() == value) {
-        this.setSelectedItem(/** @type {goog.ui.MenuItem} */ (item));
+        this.setSelectedItem(/** @type {!goog.ui.MenuItem} */ (item));
         return;
       }
     }
@@ -470,17 +471,35 @@ goog.ui.Select.prototype.updateAriaActiveDescendant_ = function() {
       goog.a11y.aria.setState(buttonElement,
           goog.a11y.aria.State.ACTIVEDESCENDANT, contentElement.id);
       if (this.selectionModel_) {
+        // We can't use selectionmodel's getItemCount here because we need to
+        // skip separators.
+        var items = this.selectionModel_.getItems();
         goog.a11y.aria.setState(contentElement, goog.a11y.aria.State.SETSIZE,
-            this.selectionModel_.getItemCount());
-        // Set a human-readable selection index.
+            this.getNumMenuItems_(items));
+        // Set a human-readable selection index, excluding menu separators.
+        var index = this.selectionModel_.getSelectedIndex();
         goog.a11y.aria.setState(contentElement, goog.a11y.aria.State.POSINSET,
-            1 + this.selectionModel_.getSelectedIndex());
+            index >= 0 ?
+            this.getNumMenuItems_(goog.array.slice(items, 0, index + 1)) : 0);
       }
     }
   }
 };
 
 
+/**
+ * Gets the number of menu items in the array.
+ * @param {!Array<?Object>} items The items.
+ * @return {number}
+ * @private
+ */
+goog.ui.Select.prototype.getNumMenuItems_ = function(items) {
+  return goog.array.count(items, function(item) {
+    return item instanceof goog.ui.MenuItem;
+  });
+};
+
+
 /**
  * Sets the correct ARIA role for the menu item or separator.
  * @param {goog.ui.MenuItem|goog.ui.MenuSeparator} item The item to set.
